# WARNING - Generated by {fusen} from /dev/flat_full.Rmd: do not edit by hand





#' Compute R-squared values for linear regression on grouped data
#'
#' This function takes a data frame, performs linear regression on specified grouping variables,
#' and computes R-squared values for each group.
#'
#' @param data A data frame containing the variables 'actual' and 'estimate' for regression.
#' @param grouping_by A character vector specifying the grouping variables for regression.
#' @return A data frame with columns 'from', 'term', and 'R2' representing the grouping variables
#' and the corresponding R-squared values.
#' @export
#' @examples
#' data <- data.frame(from = c("A", "A", "A", "A"),
#'                    term = c("X", "Y", "X", "Y"),
#'                    actual = c(1, 2, 3, 4),
#'                    estimate = c(1.5, 2.5, 3.5, 4.5))
#' compute_rsquare(data, grouping_by = c("from", "term"))
#'
#' @importFrom data.table data.table
compute_rsquare <- function(data, grouping_by =  c("from", "description") ){
  ## -- convert to data.table
  dat <- data.table::data.table(data)
  ## -- calculate the regression coefficient r^2
  r_square_df <- as.data.frame( 
                              dat[ , summary(lm(actual~estimate))$r.squared, 
                              by = grouping_by ]
                              )
  names(r_square_df)[names(r_square_df) == "V1"] <- "R2"
  return(r_square_df)
}


#' Gets R-squared values for plotting.
#'
#' This function takes a data frame with R-squared values,
#' computes position coordinates, and prepares data for plotting.
#' @param data_rsquare Data frame with R-squared values.
#' @return A data frame with additional columns for labeling in the plot.
#' @export
#' @examples
#' data_rsquare <- data.frame(from = c("A", "B", "C"), description = c("Desc1", "Desc2", "Desc3"), R2 = c(0.9, 0.8, 0.7))
#' result <- get_rsquare_2plot(data_rsquare)
get_rsquare_2plot <- function(data_rsquare){
  data_rsquare$pos_x <- -Inf
  data_rsquare$pos_y <- Inf
  data_rsquare$label_italic <- sprintf("italic(R^2) == %.2f", round(data_rsquare$R2, 3))
  data_rsquare$label_vjust <- as.numeric(factor(data_rsquare$from))
  return(data_rsquare)
}



#' Generate an identity term plot and get metrics associated
#'
#' This function generates an identity plot for comparing actual values with estimates
#'
#' @param data_identity A data frame containing comparison results with "actual" and "estimate" columns.
#' @param palette_color dict-like palette default: palette_color = c(DESeq2 = "#500472", HTRfit ="#79cbb8")
#' @param ... additional parameters to pass geom_point aes 
#' @return A ggplot2 identity plot and R2 metric associated
#'
#' @importFrom ggplot2 sym aes geom_point geom_abline facet_wrap theme_bw ggtitle scale_color_manual geom_text scale_shape_manual
#' @importFrom rlang .data new_environment
#' @export
#' @examples
#'   comparison_data <- data.frame(
#'    actual = c(1, 2, 3, 4, 5),
#'    estimate = c(0.9, 2.2, 2.8, 4.1, 5.2),
#'    description = rep("Category A", 5),
#'    term = rep("Category A", 5),
#'    from = c("A", "B", "B", "A", "B"))
#' eval_identityTerm(comparison_data)
eval_identityTerm <- function(data_identity, palette_color = c(DESeq2 = "#500472", HTRfit ="#79cbb8"),  
                               palette_shape = c(DESeq2 = 17, HTRfit = 19), ...){

  data_rsquare <- compute_rsquare(data_identity)
  data_rsquare2plot <- get_rsquare_2plot(data_rsquare)

  p <- ggplot2::ggplot(data_identity, mapping = ggplot2::aes(x = .data$actual, y = .data$estimate, col = from, shape = from,  ...) )+
    ggplot2::geom_point(alpha = 0.6, size = 2) +
    ggplot2::geom_abline(intercept = 0, slope = 1, lty = 3, col = 'red', linewidth = 1) +
    ggplot2::facet_wrap(~description, scales = "free") +
    ggplot2::theme_bw()  +
    ggplot2::geom_text(data = data_rsquare2plot,
                       mapping = ggplot2::aes(x = pos_x, y = pos_y, label = label_italic, col = from, vjust = label_vjust),
                       parse = TRUE, hjust = -0.3 ) +
    ggplot2::ggtitle("Identity plot") +
    ggplot2::scale_color_manual(values = palette_color ) + 
    ggplot2::scale_shape_manual(values = palette_shape )
  
  p$plot_env <- rlang::new_environment()

  obj_idTerm <- list(R2 = data_rsquare, p = p )

  return(obj_idTerm)
}


